@@ -4,8 +4,7 @@ use strict;
 use warnings;
 
 use File::Path 'remove_tree';
-use Test::More;
-use Test::Exception;
+use DBI;
 
 sub ready {
    if (-d 't/sql') {
@@ -14,4 +13,8 @@ sub ready {
    }
 }
 
+sub dbh {
+  DBI->connect('dbi:SQLite::memory:', undef, undef, { RaiseError => 1 })
+}
+
 1;
